#!/usr/bin/env python


"""
Autogenerated by CHEETAH: The Python-Powered Template Engine
 CHEETAH VERSION: 1.0
 Generation time: Thu Aug 17 07:48:38 2006
   Source file: xhtml.tmpl
   Source file last modified: Thu Aug 17 07:48:32 2006
"""

__CHEETAH_genTime__ = 'Thu Aug 17 07:48:38 2006'
__CHEETAH_src__ = 'xhtml.tmpl'
__CHEETAH_version__ = '1.0'

##################################################
## DEPENDENCIES

import sys
import os
import os.path
from os.path import getmtime, exists
import time
import types
import __builtin__
from Cheetah.Template import Template
from Cheetah.DummyTransaction import DummyTransaction
from Cheetah.NameMapper import NotFound, valueForName, valueFromSearchList, valueFromFrameOrSearchList
from Cheetah.CacheRegion import CacheRegion
import Cheetah.Filters as Filters
import Cheetah.ErrorCatchers as ErrorCatchers
from webskine.util import time_ago

##################################################
## MODULE CONSTANTS

try:
    True, False
except NameError:
    True, False = (1==1), (1==0)
VFFSL=valueFromFrameOrSearchList
VFSL=valueFromSearchList
VFN=valueForName
currentTime=time.time

##################################################
## CLASSES

class xhtml(Template):
    """
    
    Autogenerated by CHEETAH: The Python-Powered Template Engine
    """

    ##################################################
    ## GENERATED METHODS


    def __init__(self, *args, **KWs):
        """
        
        """

        Template.__init__(self, *args, **KWs)

    def respond(self,
            trans=None,
            VFFSL=valueFromFrameOrSearchList,
            VFN=valueForName):


        """
        This is the main method generated by Cheetah
        """

        if not trans: trans = self.transaction # is None unless self.awake() was called
        if not trans:
            trans = DummyTransaction()
            dummyTrans = True
        else: dummyTrans = False
        write = trans.response().write
        SL = self._searchList
        globalSetVars = self._globalSetVars
        filter = self._currentFilter
        
        ########################################
        ## START - generated method body
        
        write('''<!-- vim: set encoding=utf-8: -->

<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">

<head>
    <title>''')
        __v = VFFSL(SL,"title",True)
        if __v is not None: write(filter(__v, rawExpr='$title')) # from line 9, col 12.
        write('''</title>

    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
    <meta http-equiv="Content-Language" content="en-us">

    <link rel="alternate" title="Tao etc." href="''')
        __v = VFFSL(SL,"home",True)
        if __v is not None: write(filter(__v, rawExpr='${home}')) # from line 14, col 50.
        write('atom" type="application/atom+xml" />\n    <link rel="stylesheet" type="text/css" href="')
        __v = VFFSL(SL,"home",True)
        if __v is not None: write(filter(__v, rawExpr='${home}')) # from line 15, col 50.
        write('''css/style.css" />

    <script type="text/javascript">
        var jsonStore = "''')
        __v = VFFSL(SL,"home",True)
        if __v is not None: write(filter(__v, rawExpr='$home')) # from line 18, col 26.
        write('";\n    </script>\n    <script type="text/javascript" src="')
        __v = VFFSL(SL,"home",True)
        if __v is not None: write(filter(__v, rawExpr='${home}')) # from line 20, col 41.
        write('js/jquery.js"></script>\n    <script type="text/javascript" src="')
        __v = VFFSL(SL,"home",True)
        if __v is not None: write(filter(__v, rawExpr='${home}')) # from line 21, col 41.
        write('js/tinymce/jscripts/tiny_mce/tiny_mce.js"></script>\n    <script type="text/javascript" src="')
        __v = VFFSL(SL,"home",True)
        if __v is not None: write(filter(__v, rawExpr='${home}')) # from line 22, col 41.
        write('js/json.js"></script>\n    <script type="text/javascript" src="')
        __v = VFFSL(SL,"home",True)
        if __v is not None: write(filter(__v, rawExpr='${home}')) # from line 23, col 41.
        write('js/cookies.js"></script>\n    <script type="text/javascript" src="')
        __v = VFFSL(SL,"home",True)
        if __v is not None: write(filter(__v, rawExpr='${home}')) # from line 24, col 41.
        write('''js/webskine.js"></script>
</head>

<body>
    <div id="header">
        <h1><a href="''')
        __v = VFFSL(SL,"home",True)
        if __v is not None: write(filter(__v, rawExpr='$home')) # from line 29, col 22.
        write('" title="Home">')
        __v = VFFSL(SL,"title",True)
        if __v is not None: write(filter(__v, rawExpr='$title')) # from line 29, col 42.
        write('''</a></h1>
    </div>

    <div id="main">
''')
        for entry in VFFSL(SL,"entries",True):
            write('        <div class="entry" id="')
            __v = VFFSL(SL,"entry.id",True)
            if __v is not None: write(filter(__v, rawExpr='$entry.id')) # from line 34, col 32.
            write('">\n            <h2><a href="')
            __v = VFFSL(SL,"entry.id",True)
            if __v is not None: write(filter(__v, rawExpr='$entry.id')) # from line 35, col 26.
            write('" title="Permalink for this post" class="title">')
            __v = VFFSL(SL,"entry.title",True)
            if __v is not None: write(filter(__v, rawExpr='$entry.title')) # from line 35, col 83.
            write('''</a></h2>

            <div class="content">
                ''')
            __v = VFFSL(SL,"entry.content.content",True)
            if __v is not None: write(filter(__v, rawExpr='$entry.content.content')) # from line 38, col 17.
            write('''
            </div>

            <p class="footnote">Updated ''')
            __v = VFFSL(SL,"time_ago",False)(VFFSL(SL,"entry.updated",True))
            if __v is not None: write(filter(__v, rawExpr='$time_ago($entry.updated)')) # from line 41, col 41.
            write('''</p>

            <p class="break">❁</p>
        </div>
''')
        write('''    </div>

    <div id="footer">
        <p>This weblog by <a href="http://dealmeida.net/projects/webskine">webskine</a> &mdash; &copy; Roberto De Almeida 2006</p>
    </div>
</body>

</html>
''')
        
        ########################################
        ## END - generated method body
        
        return dummyTrans and trans.response().getvalue() or ""
        
    ##################################################
    ## GENERATED ATTRIBUTES


    __str__ = respond

    _mainCheetahMethod_for_xhtml= 'respond'


# CHEETAH was developed by Tavis Rudd, Mike Orr, Ian Bicking and Chuck Esterbrook;
# with code, advice and input from many other volunteers.
# For more information visit http://www.CheetahTemplate.org

##################################################
## if run from command line:
if __name__ == '__main__':
    xhtml().runAsMainProgram()




#!/usr/bin/env python


"""
Autogenerated by CHEETAH: The Python-Powered Template Engine
 CHEETAH VERSION: 1.0
 Generation time: Wed Aug 16 22:58:25 2006
   Source file: atom.tmpl
   Source file last modified: Wed Aug 16 22:58:22 2006
"""

__CHEETAH_genTime__ = 'Wed Aug 16 22:58:25 2006'
__CHEETAH_src__ = 'atom.tmpl'
__CHEETAH_version__ = '1.0'

##################################################
## DEPENDENCIES

import sys
import os
import os.path
from os.path import getmtime, exists
import time
import types
import __builtin__
from Cheetah.Template import Template
from Cheetah.DummyTransaction import DummyTransaction
from Cheetah.NameMapper import NotFound, valueForName, valueFromSearchList, valueFromFrameOrSearchList
from Cheetah.CacheRegion import CacheRegion
import Cheetah.Filters as Filters
import Cheetah.ErrorCatchers as ErrorCatchers
from cgi import escape

##################################################
## MODULE CONSTANTS

try:
    True, False
except NameError:
    True, False = (1==1), (1==0)
VFFSL=valueFromFrameOrSearchList
VFSL=valueFromSearchList
VFN=valueForName
currentTime=time.time

##################################################
## CLASSES

class atom(Template):
    """
    
    Autogenerated by CHEETAH: The Python-Powered Template Engine
    """

    ##################################################
    ## GENERATED METHODS


    def __init__(self, *args, **KWs):
        """
        
        """

        Template.__init__(self, *args, **KWs)

    def respond(self,
            trans=None,
            VFFSL=valueFromFrameOrSearchList,
            VFN=valueForName):


        """
        This is the main method generated by Cheetah
        """

        if not trans: trans = self.transaction # is None unless self.awake() was called
        if not trans:
            trans = DummyTransaction()
            dummyTrans = True
        else: dummyTrans = False
        write = trans.response().write
        SL = self._searchList
        globalSetVars = self._globalSetVars
        filter = self._currentFilter
        
        ########################################
        ## START - generated method body
        
        write('''<?xml version="1.0" encoding="utf-8"?>
<feed xmlns="http://www.w3.org/2005/Atom">

    <title type="html">''')
        __v = VFFSL(SL,"title",True)
        if __v is not None: write(filter(__v, rawExpr='$title')) # from line 5, col 24.
        write('</title>\n    <link rel="self" href="')
        __v = VFFSL(SL,"feed",True)
        if __v is not None: write(filter(__v, rawExpr='$feed')) # from line 6, col 28.
        write('"/>\n    <updated>')
        __v = VFN(VFFSL(SL,"updated",True),"strftime",False)('%Y-%m-%dT%H:%M:%SZ')
        if __v is not None: write(filter(__v, rawExpr="$updated.strftime('%Y-%m-%dT%H:%M:%SZ')")) # from line 7, col 14.
        write('''</updated>
    <author>
        <name>Roberto De Almeida</name>
        <email>roberto@dealmeida.net</email>
        <uri>http://dealmeida.net</uri>
    </author>
    <id>''')
        __v = VFFSL(SL,"home",True)
        if __v is not None: write(filter(__v, rawExpr='$home')) # from line 13, col 9.
        write('</id>\n\n')
        for entry in VFFSL(SL,"entries",True):
            write('    <entry>\n        <title>')
            __v = VFFSL(SL,"entry.title",True)
            if __v is not None: write(filter(__v, rawExpr='$entry.title')) # from line 17, col 16.
            write('</title>\n        <link href="')
            __v = VFFSL(SL,"entry.id",True)
            if __v is not None: write(filter(__v, rawExpr='$entry.id')) # from line 18, col 21.
            write('"/>\n        <id>')
            __v = VFFSL(SL,"entry.id",True)
            if __v is not None: write(filter(__v, rawExpr='$entry.id')) # from line 19, col 13.
            write('</id>\n        <updated>')
            __v = VFN(VFFSL(SL,"entry.updated",True),"strftime",False)('%Y-%m-%dT%H:%M:%SZ')
            if __v is not None: write(filter(__v, rawExpr="$entry.updated.strftime('%Y-%m-%dT%H:%M:%SZ')")) # from line 20, col 18.
            write('</updated>\n        <content type="html">')
            __v = VFFSL(SL,"escape",False)(VFFSL(SL,"entry.content.content",True))
            if __v is not None: write(filter(__v, rawExpr='$escape($entry.content.content)')) # from line 21, col 30.
            write('''</content>
    </entry>

''')
        write('</feed>\n')
        
        ########################################
        ## END - generated method body
        
        return dummyTrans and trans.response().getvalue() or ""
        
    ##################################################
    ## GENERATED ATTRIBUTES


    __str__ = respond

    _mainCheetahMethod_for_atom= 'respond'


# CHEETAH was developed by Tavis Rudd, Mike Orr, Ian Bicking and Chuck Esterbrook;
# with code, advice and input from many other volunteers.
# For more information visit http://www.CheetahTemplate.org

##################################################
## if run from command line:
if __name__ == '__main__':
    atom().runAsMainProgram()




import re
import datetime
from urlparse import urljoin
from cgi import escape

from paste import httpexceptions
from paste.request import construct_url
from paste.auth.digest import digest_password, AuthDigestHandler

from atomstorage import EntryManager
from jsonstore.jsonstore import JSONStore
from webskine.templates import xhtml, atom
from webskine.middleware import ContentMiddleware


def make_app(global_conf, title='', dsn='shelve://entries.db', entries=10, user='test', password='test', **kwargs):
    """
    Create a weblog.

    Configuration should be like this::

        [app:weblob]
        use = egg:webskine
        title = Weblog title
        dsn = protocol://location  # for atomstorage
        entries = 10
        user = username
        password = *******
    """
    # Apps we're using.
    webskine = Webskine(title, dsn, entries)
    jsonstore = JSONStore(dsn) 

    # Add authentication to the JSON store.
    def authfunc(environ, realm, username):
        return digest_password(realm, user, password)
    jsonstore = AuthDigestHandler(jsonstore, title, authfunc)

    # Pass application/json requests to jsonstore, all others to webskine.
    mapping = [ ('application/json', jsonstore),
                ('.*', webskine) ]

    app = ContentMiddleware(mapping)
    return app


class Webskine(object):
    def __init__(self, title, dsn, entries):
        self.title = title
        self.entries = entries

        # Get entry manager.
        self.em = EntryManager(dsn)

    def __call__(self, environ, start_response):
        self.environ = environ
        self.start = start_response

        # Parse request.
        dispatchers = [ ('/atom', lambda d: self._atom()),
                        ('/(?P<id>\d+)?', lambda d: self._entry(**d)), ]
        path_info = environ.get('PATH_INFO', '/')
        for regexp, func in dispatchers:
            p = re.compile(regexp)
            m = p.match(path_info)
            if m:
                reqdict = m.groupdict()
                return func(reqdict)
        
        # Raise 404.
        raise httpexceptions.HTTPNotFound()

    def _entry(self, id):
        """
        Return entry or list of entries.

        Return a single entry if id is specified. Otherwise,
        return last self.entries entries.
        """
        if id is None:  
            entries = self.em.get_entries(self.entries)
        else:
            try:
                entries = [self.em.get_entry(id)]
            except KeyError:
                raise httpexceptions.HTTPNotFound()

        # Update entry with a proper id (pointing to the resource location)
        # and a nicely formated updated timestamp.
        location = construct_url(self.environ, with_query_string=False, with_path_info=False) + '/'
        now = datetime.datetime.utcnow()
        for entry in entries:
            entry['id'] = urljoin(location, entry['id'])
            entry.setdefault('content', {'content': ''})
            
        namespace = {'title': self.title, 'home': location, 'entries': entries}
        output = xhtml.xhtml(searchList=[namespace], filter='EncodeUnicode')
        output = str(output)

        headers = [('Content-Encoding', 'utf-8'),
                   ('Content-Type', 'text/html')]
        self.start('200 OK', headers)
        return [output] 

    def _atom(self):
        """
        Return an atom feed.
        """
        entries = self.em.get_entries(self.entries)

        # Update entry with a proper id (pointing to the resource location)
        # and a nicely formated updated timestamp.
        location = construct_url(self.environ, with_query_string=False, with_path_info=False) + '/'
        now = datetime.datetime.utcnow()
        for entry in entries:
            entry['id'] = urljoin(location, entry['id'])
            entry.setdefault('content', {'content': ''})

        namespace = {'title': self.title,
                     'feed': urljoin(location, 'atom'),
                     'updated': entries[0]['updated'],
                     'home': location,
                     'entries': entries}
        output = atom.atom(searchList=[namespace], filter='EncodeUnicode')
        output = str(output)

        headers = [('Content-Encoding', 'utf-8'),
                   ('Content-Type', 'application/atom+xml')]
        self.start('200 OK', headers)
        return [output]

    def close(self):
        self.em.close()
